@@ -17,6 +17,7 @@ import json
 import mock
 
 import sushy
+from sushy.resources import constants as res_cons
 from sushy.resources.system import processor
 from sushy.tests.unit import base
 
@@ -26,8 +27,8 @@ class ProcessorTestCase(base.TestCase):
     def setUp(self):
         super(ProcessorTestCase, self).setUp()
         self.conn = mock.Mock()
-        with open('sushy/tests/unit/json_samples/processor.json', 'r') as f:
-            self.conn.get.return_value.json.return_value = json.loads(f.read())
+        with open('sushy/tests/unit/json_samples/processor.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
 
         self.sys_processor = processor.Processor(
             self.conn, '/redfish/v1/Systems/437XR1138R2/Processors/CPU1',
@@ -63,9 +64,11 @@ class ProcessorTestCase(base.TestCase):
         self.assertEqual(3700, self.sys_processor.max_speed_mhz)
         self.assertEqual(8, self.sys_processor.total_cores)
         self.assertEqual(16, self.sys_processor.total_threads)
-        self.assertEqual('Enabled', self.sys_processor.status.state)
-        self.assertEqual('OK', self.sys_processor.status.health)
-        self.assertEqual('OK', self.sys_processor.status.health_rollup)
+        self.assertEqual(res_cons.STATE_ENABLED,
+                         self.sys_processor.status.state)
+        self.assertEqual(res_cons.HEALTH_OK, self.sys_processor.status.health)
+        self.assertEqual(res_cons.HEALTH_OK,
+                         self.sys_processor.status.health_rollup)
 
 
 class ProcessorCollectionTestCase(base.TestCase):
@@ -74,8 +77,8 @@ class ProcessorCollectionTestCase(base.TestCase):
         super(ProcessorCollectionTestCase, self).setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
-                  'processor_collection.json', 'r') as f:
-            self.conn.get.return_value.json.return_value = json.loads(f.read())
+                  'processor_collection.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
         self.sys_processor_col = processor.ProcessorCollection(
             self.conn, '/redfish/v1/Systems/437XR1138R2/Processors',
             redfish_version='1.0.2')
@@ -115,10 +118,11 @@ class ProcessorCollectionTestCase(base.TestCase):
     def _setUp_processor_summary(self):
         self.conn.get.return_value.json.reset_mock()
         successive_return_values = []
-        with open('sushy/tests/unit/json_samples/processor.json', 'r') as f:
-            successive_return_values.append(json.loads(f.read()))
-        with open('sushy/tests/unit/json_samples/processor2.json', 'r') as f:
-            successive_return_values.append(json.loads(f.read()))
+        file_names = ['sushy/tests/unit/json_samples/processor.json',
+                      'sushy/tests/unit/json_samples/processor2.json']
+        for file_name in file_names:
+            with open(file_name) as f:
+                successive_return_values.append(json.load(f))
 
         self.conn.get.return_value.json.side_effect = successive_return_values
 
@@ -155,8 +159,8 @@ class ProcessorCollectionTestCase(base.TestCase):
         self.conn.get.return_value.json.side_effect = None
         # On refreshing the sys_processor_col instance...
         with open('sushy/tests/unit/json_samples/'
-                  'processor_collection.json', 'r') as f:
-            self.conn.get.return_value.json.return_value = json.loads(f.read())
+                  'processor_collection.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
         self.sys_processor_col.refresh(force=True)
 
         # | WHEN & THEN |
